"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const getI18nMessages_1 = require("./getI18nMessages");
describe("getI18nMessages", () => {
    it("should create messages for entity without fields", () => {
        const result = getI18nMessages_1.getI18nMessages("Entity", []);
        chai_1.expect(result).to.deep.equal({
            resources: {
                Entity: {
                    name: "Entity |||| Entities",
                    fields: {},
                },
            },
        });
    });
    it("should create messages for entity with one field", () => {
        const result = getI18nMessages_1.getI18nMessages("Entity", [
            {
                name: "key",
                displayName: "value",
            },
        ]);
        chai_1.expect(result).to.deep.equal({
            resources: {
                Entity: {
                    name: "Entity |||| Entities",
                    fields: {
                        key: "value"
                    }
                }
            }
        });
    });
    it("should create messages for entity with two fields", () => {
        const result = getI18nMessages_1.getI18nMessages("Entity", [
            {
                name: "key1",
                displayName: "value1",
            },
            {
                name: "key2",
                displayName: "value2",
            },
        ]);
        chai_1.expect(result).to.deep.equal({
            resources: {
                Entity: {
                    name: "Entity |||| Entities",
                    fields: {
                        key1: "value1",
                        key2: "value2",
                    },
                },
            },
        });
    });
    it("should remove 'Dto' suffix from entity name, when creating message value for 'name'", () => {
        chai_1.expect(getI18nMessages_1.getI18nMessages("EntityDto", [])).to.deep.equal({
            resources: {
                EntityDto: {
                    name: "Entity |||| Entities",
                    fields: {},
                },
            },
        });
        chai_1.expect(getI18nMessages_1.getI18nMessages("EntityDTO", [])).to.deep.equal({
            resources: {
                EntityDTO: {
                    name: "Entity |||| Entities",
                    fields: {},
                },
            },
        });
    });
    it("should not remove 'Dto', if full entity name is 'Dto'", function () {
        chai_1.expect(getI18nMessages_1.getI18nMessages("Dto", [])).to.deep.equal({
            resources: {
                Dto: {
                    name: "Dto |||| Dtos",
                    fields: {},
                },
            },
        });
    });
    it("should not replace 'Dto' in the middle of entity name", function () {
        chai_1.expect(getI18nMessages_1.getI18nMessages("EntityDtoOne", [])).to.deep.equal({
            resources: {
                EntityDtoOne: {
                    name: "EntityDtoOne |||| EntityDtoOnes",
                    fields: {},
                },
            },
        });
    });
    it("should create messages for entity with enum field", () => {
        const result = getI18nMessages_1.getI18nMessages("Entity", [
            {
                name: "enumAttrName",
                displayName: "enumAttrDisplayName",
                gqlType: "EnumTypeName",
                enumOptions: [
                    {
                        name: "VALUE_ONE",
                        value: "VALUE_ONE",
                    },
                    {
                        name: "VALUE_TWO",
                        value: "VALUE_TWO",
                    },
                ],
            },
        ]);
        chai_1.expect(result).to.deep.equal({
            resources: {
                Entity: {
                    name: "Entity |||| Entities",
                    fields: {
                        enumAttrName: "enumAttrDisplayName",
                    },
                },
            },
            enums: {
                EnumTypeName: {
                    VALUE_ONE: "Value one",
                    VALUE_TWO: "Value two",
                },
            },
        });
    });
});
//# sourceMappingURL=getI18nMessages.test.js.map