"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mergeI18nMessagesWithLocaleFileContent_1 = require("./mergeI18nMessagesWithLocaleFileContent");
const jscodeshift_1 = __importDefault(require("jscodeshift"));
const chai_1 = require("chai");
const getI18nMessages_1 = require("../../../../building-blocks/stages/template-model/pieces/getI18nMessages");
describe("parseMessagesToNode", async () => {
    it("should parse simple string messages", () => {
        const astNode = mergeI18nMessagesWithLocaleFileContent_1.parseMessagesToNode({
            messageOne: 'messageOne',
            messageTwo: 'messageTwo'
        });
        const stringMessages = jscodeshift_1.default(astNode).toSource();
        chai_1.expect(stringMessages).to.deep.equal(`{
    messageOne: "messageOne",
    messageTwo: "messageTwo"
}`);
    });
    it("should parse SpreadElement inside messages", () => {
        const astNode = mergeI18nMessagesWithLocaleFileContent_1.parseMessagesToNode({
            englishMessages: new getI18nMessages_1.SpreadElement()
        });
        const stringMessages = jscodeshift_1.default(astNode).toSource();
        chai_1.expect(stringMessages).to.deep.equal(`{
    ...englishMessages
}`);
    });
    it("should parse deep string messages", () => {
        const astNode = mergeI18nMessagesWithLocaleFileContent_1.parseMessagesToNode({
            levelOne: {
                levelTwo: {
                    messageOne: 'messageOne',
                    messageTwo: 'messageTwo'
                }
            }
        });
        const stringMessages = jscodeshift_1.default(astNode).toSource();
        chai_1.expect(stringMessages).to.deep.equal(`{
    levelOne: {
        levelTwo: {
            messageOne: "messageOne",
            messageTwo: "messageTwo"
        }
    }
}`);
    });
    it("should parse all combination of possible messages", () => {
        const astNode = mergeI18nMessagesWithLocaleFileContent_1.parseMessagesToNode({
            englishMessages: new getI18nMessages_1.SpreadElement(),
            messageOne: 'messageOne',
            messageTwo: 'messageTwo',
            levelOne: {
                levelTwo: {
                    messageOne: 'messageOne',
                    messageTwo: 'messageTwo'
                }
            }
        });
        const stringMessages = jscodeshift_1.default(astNode).toSource();
        chai_1.expect(stringMessages).to.deep.equal(`{
    ...englishMessages,
    messageOne: "messageOne",
    messageTwo: "messageTwo",

    levelOne: {
        levelTwo: {
            messageOne: "messageOne",
            messageTwo: "messageTwo"
        }
    }
}`);
    });
});
//# sourceMappingURL=parseMessagesToNode.test.js.map